=============
API Reference
=============

This page contains the documentation of the public API. The pharmpy-module includes the model object and
the classes related to it (parameters, statements, random variables etc.), the modeling-module handles
different transformations and manipulations, and the workflows-module is how different tools are built and run.

.. toctree::
   :maxdepth: 1

   api_pharmpy
   api_modeling
   api_workflows
